'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.parseCLIArg = exports.progressMap = exports.exitUsage = exports.TOKEN = exports.log = undefined;

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

var _asciiProgress = require('ascii-progress');

var _asciiProgress2 = _interopRequireDefault(_asciiProgress);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var log = exports.log = function log() {
  var _console;

  return (_console = console).error.apply(_console, arguments);
}; /* eslint-disable no-console */

var TOKEN = exports.TOKEN = process.env.PLEX_TOKEN;

var exitUsage = exports.exitUsage = function exitUsage() {
  console.error('\nUsage: plex-sync [token@]IP[:PORT]/SECTION[,rw] [token@]IP[:PORT]/SECTION[,rw] [[token@]IP[:PORT]/SECTION[,rw]...]\n\nExample:\n\n    Sync section 1 on a server with the default port with section 2 on another server:\n    $ plex-sync 10.0.1.2/1 10.0.1.3:32401/2\n\n    Sync three servers:\n    $ plex-sync 10.0.1.2/1 10.0.1.3/1 10.0.1.4/1\n\n    Dry run, to see what the script will do:\n    $ DRY_RUN=1 plex-sync 10.0.1.5/1 10.0.1.5/1\n\n    Precise matching (slow and may crash the Plex server):\n    $ MATCH_TYPE=precise plex-sync 10.0.1.5/1 10.0.1.5/1\n\n    Syncing between multiple Plex users (different access tokens):\n    $ plex-sync xxxxxx@10.0.1.5/1 zzzzzz@10.0.1.10/3\n\n    Unidirectional sync (read from one server, write to the other):\n    $ plex-sync 10.0.1.5/1,r 10.0.1.10/3,w\n\n    Complex use case:\n    $ plex-sync xxxx@10.0.1.5:32401/1,r yyyy@10.0.1.10/3,w zzzz@10.0.1.15/2,rw\n'.trim());
  process.exit(1);
};

var progressMap = exports.progressMap = function progressMap(items, fn) {
  var progress = new _asciiProgress2.default({ total: items.length });

  return _promise2.default.all(items.map(function () {
    progress.tick();
    return fn.apply(undefined, arguments);
  }));
};

var parseCLIArg = exports.parseCLIArg = function parseCLIArg(arg) {
  var matches = arg.match(/^(([^@]+)@)?(([^:]+)(:\d+)?)\/(\d+)(,[rw][rw])?$/);
  if (!matches) exitUsage();
  var token = matches[2] || TOKEN;
  var host = '' + matches[4] + (matches[5] || ':32400');
  var section = matches[6] || '1';
  var modeString = matches[8] || 'rw';
  var mode = {
    read: modeString.includes('r'),
    write: modeString.includes('w')
  };
  return { token: token, host: host, section: section, mode: mode };
};